@@ -3,4 +3,6 @@
 /* The name of this package (not localized) */
 var PACKAGE_NAME = 'cinnamon';
 /* The version of this package */
-var PACKAGE_VERSION = '5.8.4';
+var PACKAGE_VERSION = '6.4.9';
+/* 1 if networkmanager is available, 0 otherwise */
+var HAVE_NETWORKMANAGER = 1;
